#![warn(clippy::all, rust_2018_idioms)]
#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")] // hide console window on Windows in release

use eframe;
use egui;
use image;

mod app;

// When compiling natively:
#[cfg(not(target_arch = "wasm32"))]
fn main() -> eframe::Result {
    use egui::IconData;

    env_logger::init(); // Log to stderr (if you run with `RUST_LOG=debug`).

    let icon = IconData {
        rgba: image::load_from_memory(&include_bytes!("../assets/icon-512.jpg")[..])
            .expect("could not decode the bundled icon")
            .to_rgba8()
            .into_vec(),
        width: 512,
        height: 512,
    };
    let native_options = eframe::NativeOptions {
        viewport: egui::ViewportBuilder::default()
            .with_inner_size([400.0, 300.0])
            .with_min_inner_size([300.0, 220.0])
            .with_icon(icon),
        ..Default::default()
    };
    eframe::run_native(
        app::TITLE,
        native_options,
        Box::new(|cc| Ok(Box::new(app::RollatorApp::new_with_cli(cc)))),
    )
}

// TODO: add a main for compiling to wasm
